==> cvsnotify-1.0.0.tar.gz: cvsnotify-1.0.0/cvsnotify-logsend.pl <==
#!/usr/bin/env perl

####################################################################
# CVS Activity Notifying Tool
# $Id: cvsnotify-logsend.pl,v 1.1 2004/03/15 22:46:00 pynoos Exp $
# Copyright (C) 2004 by Hojin Choi <pynoos@users.kldp.net>
# You can redistribute this software under GPL.
####################################################################

#pre-defined vars: $module
local $logsend_message;
local $logsend_email;

sub logsend_preprocess()
{
	$logsend_message = "";
	$logsend_email = get_matched_value( $module, "log_notify", "cvsnotifysub-logsend");
	return;
}

sub logsend_foreach($$$)
{
	my ( $file, $old, $new ) = @_;
	my( $url_old_file, $url_new_file, $url_diff_file );
	my( $msglog );
	my $cvsurl = $conf{'cvsurl'};
	my $subrootenc = $conf{'subrootenc'};
	my $cvsmarkupcontenttype = $conf{'cvsmarkupcontenttype'};
	my $cvsdiffoption = $conf{'cvsdiffoption'};
	my( $url_file) = "$cvsurl/$module";
	$url_file .= "?$subroot" if $subroot;
	$url_file .= "/$file";

	if( $old eq "NONE" )
	{
		$msglog = $tpl{'LOGSEND_NEW_FILE'};
		$url_new_file = "$cvsurl/$module/$file?$subrootenc"."rev=$new&content-type=$cvsmarkupcontenttype";
		$url_new_annotate = "$cvsurl/$module/$file?$subrootenc"."annotate=$new";
		$url_new_download = "$cvsurl/*checkout*/$module/$file?$subrootenc"."rev=$new";
		$annotate_new = "a";
		$download_new = "d";
		$annotate_old = "";
		$download_old = "";
	}
	elsif( $new eq "NONE" )
	{
		$msglog = $tpl{'LOGSEND_DELETE_FILE'};
		$url_old_file = "$cvsurl/$module/$file?$subrootenc"."rev=$old&content-type=$cvsmarkupcontenttype";
		$url_old_annotate = "$cvsurl/$module/$file?$subrootenc"."annotate=$old";
		$url_old_download = "$cvsurl/*checkout*/$module/$file?$subrootenc"."rev=$old";
		$annotate_new = "";
		$download_new = "";
		$annotate_old = "a";
		$download_old = "d";
	}
	else
	{
		$msglog = $tpl{'LOGSEND_MODIFIED_FILE'};
		$url_new_file = "$cvsurl/$module/$file?$subrootenc"."rev=$new&content-type=$cvsmarkupcontenttype";
		$url_old_file = "$cvsurl/$module/$file?$subrootenc"."rev=$old&content-type=$cvsmarkupcontenttype";
		$url_diff_file = "$cvsurl/$module/$file.diff?$subrootenc"."r1=$old&r2=$new&$cvsdiffoption";
		$url_new_annotate = "$cvsurl/$module/$file?$subrootenc"."annotate=$new";
		$url_old_annotate = "$cvsurl/$module/$file?$subrootenc"."annotate=$old";
		$url_new_download = "$cvsurl/*checkout*/$module/$file?$subrootenc"."rev=$new";
		$url_old_download = "$cvsurl/*checkout*/$module/$file?$subrootenc"."rev=$old";
		$annotate_new = "a";
		$download_new = "d";
		$annotate_old = "a";
		$download_old = "d";
	}
	$msglog =~ s/{FILE}/$file/g;
	$msglog =~ s/{REV_NEW}/$new/g;
	$msglog =~ s/{REV_OLD}/$old/g;
	$msglog =~ s/{URL_FILE}/$url_file/g;
	$msglog =~ s/{URL_DIFF}/$url_diff_file/g;
	$msglog =~ s/{URL_NEW}/$url_new_file/g;
	$msglog =~ s/{URL_OLD}/$url_old_file/g;
	$msglog =~ s/{URL_NEW_ANNOTATE}/$url_new_annotate/g;
	$msglog =~ s/{URL_OLD_ANNOTATE}/$url_old_annotate/g;
	$msglog =~ s/{URL_NEW_DOWNLOAD}/$url_new_download/g;
	$msglog =~ s/{URL_OLD_DOWNLOAD}/$url_old_download/g;
	$msglog =~ s/{ANNOTATE_NEW}/$annotate_new/g;
	$msglog =~ s/{ANNOTATE_OLD}/$annotate_old/g;
	$msglog =~ s/{DOWNLOAD_NEW}/$download_new/g;
	$msglog =~ s/{DOWNLOAD_OLD}/$download_old/g;

	$logsend_message .= $msglog;
	return 1;
}

sub logsend_postprocess()
{
	my $cvsurl = $conf{'cvsurl'};
	my $template = $tpl{'LOGSEND_HEADER'} . $logsend_message . $tpl{'LOGSEND_FOOTER'};
	my( $url_module ) = "$cvsurl/$module";
	$url_module .= "?$subroot" if $subroot;
	my %tplhash = (
		LOG => $loginfo_logmsg,
		FROM => $whoami. "@" . $conf{'maildomain'},
		TO => $logsend_email,
		MODULE => $module,
		URL_MODULE => $url_module,
		CONTENT => $content );

	print "cvsnotifysub-logsend: Commit log of '$module' will be sent to $logsend_email\n";
	_sendmail( replace_template( $template, %tplhash) );
}

# End of script.
1

==> cvsnotify-1.0.1.tar.gz: cvsnotify-1.0.1/cvsnotify-logsend.pl <==
#!/usr/bin/env perl

####################################################################
# CVS Activity Notifying Tool
# $Id: cvsnotify-logsend.pl,v 1.3 2004/05/18 12:52:23 pynoos Exp $
# Copyright (C) 2004 by Hojin Choi <pynoos@users.kldp.net>
# You can redistribute this software under GPL.
####################################################################

#pre-defined vars: $module
local $logsend_message;
local $logsend_email;

sub logsend_preprocess()
{
	$logsend_message = "";
	$logsend_email = get_matched_value( $module, "log_notify", "cvsnotify-logsend");
	return;
}

sub logsend_foreach($$$)
{
	my ( $file, $old, $new ) = @_;
	my( $url_old_file, $url_new_file, $url_diff_file );
	my( $msglog );
	my $cvsurl = $conf{'cvsurl'};
	my $subrootenc = $conf{'subrootenc'};
	my $cvsmarkupcontenttype = $conf{'cvsmarkupcontenttype'};
	my $cvsdiffoption = $conf{'cvsdiffoption'};
	my( $url_file) = "$cvsurl/$module";
	$url_file .= "?$subroot" if $subroot;
	$url_file .= "/$file";

	if( $old eq "NONE" )
	{
		$msglog = $tpl{'LOGSEND_NEW_FILE'};
		$url_new_file = "$cvsurl/$module/$file?$subrootenc"."rev=$new&content-type=$cvsmarkupcontenttype";
		$url_new_annotate = "$cvsurl/$module/$file?$subrootenc"."annotate=$new";
		$url_new_download = "$cvsurl/*checkout*/$module/$file?$subrootenc"."rev=$new";
		$annotate_new = "a";
		$download_new = "d";
		$annotate_old = "";
		$download_old = "";
	}
	elsif( $new eq "NONE" )
	{
		$msglog = $tpl{'LOGSEND_DELETE_FILE'};
		$url_old_file = "$cvsurl/$module/$file?$subrootenc"."rev=$old&content-type=$cvsmarkupcontenttype";
		$url_old_annotate = "$cvsurl/$module/$file?$subrootenc"."annotate=$old";
		$url_old_download = "$cvsurl/*checkout*/$module/$file?$subrootenc"."rev=$old";
		$annotate_new = "";
		$download_new = "";
		$annotate_old = "a";
		$download_old = "d";
	}
	else
	{
		$msglog = $tpl{'LOGSEND_MODIFIED_FILE'};
		$url_new_file = "$cvsurl/$module/$file?$subrootenc"."rev=$new&content-type=$cvsmarkupcontenttype";
		$url_old_file = "$cvsurl/$module/$file?$subrootenc"."rev=$old&content-type=$cvsmarkupcontenttype";
		$url_diff_file = "$cvsurl/$module/$file.diff?$subrootenc"."r1=$old&r2=$new&$cvsdiffoption";
		$url_new_annotate = "$cvsurl/$module/$file?$subrootenc"."annotate=$new";
		$url_old_annotate = "$cvsurl/$module/$file?$subrootenc"."annotate=$old";
		$url_new_download = "$cvsurl/*checkout*/$module/$file?$subrootenc"."rev=$new";
		$url_old_download = "$cvsurl/*checkout*/$module/$file?$subrootenc"."rev=$old";
		$annotate_new = "a";
		$download_new = "d";
		$annotate_old = "a";
		$download_old = "d";
	}
	$msglog =~ s/{FILE}/$file/g;
	$msglog =~ s/{REV_NEW}/$new/g;
	$msglog =~ s/{REV_OLD}/$old/g;
	$msglog =~ s/{URL_FILE}/$url_file/g;
	$msglog =~ s/{URL_DIFF}/$url_diff_file/g;
	$msglog =~ s/{URL_NEW}/$url_new_file/g;
	$msglog =~ s/{URL_OLD}/$url_old_file/g;
	$msglog =~ s/{URL_NEW_ANNOTATE}/$url_new_annotate/g;
	$msglog =~ s/{URL_OLD_ANNOTATE}/$url_old_annotate/g;
	$msglog =~ s/{URL_NEW_DOWNLOAD}/$url_new_download/g;
	$msglog =~ s/{URL_OLD_DOWNLOAD}/$url_old_download/g;
	$msglog =~ s/{ANNOTATE_NEW}/$annotate_new/g;
	$msglog =~ s/{ANNOTATE_OLD}/$annotate_old/g;
	$msglog =~ s/{DOWNLOAD_NEW}/$download_new/g;
	$msglog =~ s/{DOWNLOAD_OLD}/$download_old/g;

	$logsend_message .= $msglog;
	return 1;
}

sub logsend_postprocess()
{
	my $cvsurl = $conf{'cvsurl'};
	my( $url_module ) = "$cvsurl/$module";
	$url_module .= "?$subroot" if $subroot;
	my %tplhash = (
		LOG => $loginfo_logmsg,
		FROM => $whoami. "@" . $conf{'maildomain'},
		TO => $logsend_email,
		MODULE => $module,
		URL_MODULE => $url_module,
		CONTENT => $content );


	print $log "Last module check: [$module] [" . get_last_dir() . "]\n";

	open LOGMESSAGE, ">>$TMPDIR/.#$whoami.logmessage" or return;
	print LOGMESSAGE replace_template( $tpl{'LOGSEND_MODULE'} . $logsend_message, %tplhash);
	close ( LOGMESSAGE );

	if( $module eq get_last_dir() )
	{
		print "cvsnotify-logsend: Commit log of '$module' will be sent to $logsend_email\n";
		my $template = $tpl{'LOGSEND_HEADER'};
		open LOGMESSAGE, "$TMPDIR/.#$whoami.logmessage" or return;
		while( <LOGMESSAGE> )
		{
			$template .= $_;
		}
		close( LOGMESSAGE );
		$template .= $tpl{'LOGSEND_FOOTER'};
		_sendmail( replace_template( $template, %tplhash ) );
		unlink "$TMPDIR/.#$whoami.logmessage";
		unlink_last_dir_info();
		print $log "BINGO!!\n";
	}
}

# End of script.
1
